Schema registry for loading, managing, and accessing SCIM schemas.
This module provides the SchemaRegistry which handles schema loading from files, schema management, and provides access to registered schemas for validation.
Structs
- Schema
Registry - Registry for SCIM schemas with validation capabilities.